@@ -1,14 +1,16 @@
+import copy
 from bisect import insort
 from enum import Enum
 from pathlib import Path
 from typing import Sequence
-import copy
 
 from construct import Container, ListContainer
 
 from open_dread_rando.common_data import ALL_SCENARIOS
 from open_dread_rando.patcher_editor import PatcherEditor
 
+from mercury_engine_data_structures.formats import Bmscc
+
 # copied from existing entity, so we don't have to make a whole shield
 _EXAMPLE_SHIELD = {"scenario": "s010_cave", "layer": "default", "actor": "Door003_missileShield"}
 
@@ -32,8 +34,10 @@ class MinimapIconData(Enum):
     SHIELD_WIDE_BEAM = ("DoorWide", (-300, -150, 0, 300))
     SHIELD_PLASMA_BEAM = ("BlockagePlasma", (-300, -150, 0, 300))
     SHIELD_WAVE_BEAM = ("BlockageWave", (-300, -150, 0, 300))
+    SHIELD_DIFFUSION = ("BlockageDiffusion", (-300, -150, 0, 300))
     SHIELD_MISSILE = ("BlockageMissile", (-300, -150, 0, 300))
     SHIELD_SUPER_MISSILE = ("BlockageSuperMissile", (-300, -150, 0, 300))
+    SHIELD_ICE_MISSILE = ("BlockageIce", (-300, -150, 0, 300))
 
     def __init__(self, icon_id: str, offsets: tuple[float, float, float, float]):
         """
@@ -73,7 +77,7 @@ class MinimapIconData(Enum):
             Min=ListContainer([pos[0] + self.oBox_min[0] + delta, pos[1] + self.oBox_min[1]]),
             Max=ListContainer([pos[0] + self.oBox_max[0] + delta, pos[1] + self.oBox_max[1]]))
         cont["sIconId"] = f"{self.icon_id}{dir}"
-        cont["bFlipX"] = False
+        cont["bFlipX"] = False if dir == "L" else True
         cont["bFlipY"] = False
 
         return cont
@@ -94,8 +98,10 @@ class ActorData(Enum):
     SHIELD_WIDE_BEAM = (["doorwidebeam"], MinimapIconData.SHIELD_WIDE_BEAM)
     SHIELD_PLASMA_BEAM = (["door_shield_plasma"], MinimapIconData.SHIELD_PLASMA_BEAM)
     SHIELD_WAVE_BEAM = (["doorwavebeam"], MinimapIconData.SHIELD_WAVE_BEAM)
+    SHIELD_DIFFUSION_BEAM = (["shield___diffusion"], MinimapIconData.SHIELD_DIFFUSION)
     SHIELD_MISSILE = (["doorshieldmissile"], MinimapIconData.SHIELD_MISSILE)
     SHIELD_SUPER_MISSILE = (["doorshieldsupermissile"], MinimapIconData.SHIELD_SUPER_MISSILE)
+    SHIELD_ICE_MISSILE = (["shield_icemissile"], MinimapIconData.SHIELD_ICE_MISSILE)
 
     def __init__(self, actordef: list[str], minimap: MinimapIconData):
         # generate actordefs
@@ -115,16 +121,24 @@ class DoorType(Enum):
     FRAME = ("frame", ActorData.DOOR_FRAME)
     POWER = ("power_beam", ActorData.DOOR_POWER)
     CHARGE = ("charge_beam", ActorData.DOOR_CHARGE)
-    WIDE_BEAM = ("wide_beam", ActorData.DOOR_POWER, True, ActorData.SHIELD_WIDE_BEAM, True, True, ["actors/props/doorshieldmissile"])
+    DIFFUSION = ("diffusion_beam", ActorData.DOOR_POWER, True, ActorData.SHIELD_DIFFUSION_BEAM, True, True, 
+                 ["actors/props/door_shield_plasma"])
+    WIDE_BEAM = ("wide_beam", ActorData.DOOR_POWER, True, ActorData.SHIELD_WIDE_BEAM, True, True, 
+                 ["actors/props/doorshieldmissile"])
     PLASMA_BEAM = ("plasma_beam", ActorData.DOOR_POWER, True, ActorData.SHIELD_PLASMA_BEAM)
     WAVE_BEAM = ("wave_beam", ActorData.DOOR_POWER, True, ActorData.SHIELD_WAVE_BEAM)
     MISSILE = ("missile", ActorData.DOOR_POWER, True, ActorData.SHIELD_MISSILE)
     SUPER_MISSILE = ("super_missile", ActorData.DOOR_POWER, True, ActorData.SHIELD_SUPER_MISSILE)
-    GRAPPLE = ("grapple_beam", ActorData.DOOR_GRAPPLE, False, None, True, True, ["actors/props/door"])
-    PRESENCE = ("phantom_cloak", ActorData.DOOR_PRESENCE, False, None, True, False, ["actors/props/door"])
+    ICE_MISSILE = ("ice_missile", ActorData.DOOR_POWER, True, ActorData.SHIELD_ICE_MISSILE, True, True, 
+                   ["actors/props/doorshieldmissile"])
+    GRAPPLE = ("grapple_beam", ActorData.DOOR_GRAPPLE, False, None, True, True, 
+               ["actors/props/door"])
+    PRESENCE = ("phantom_cloak", ActorData.DOOR_PRESENCE, False, None, True, False, 
+                ["actors/props/door"])
 
     def __init__(self, rdv_door_type: str, door_data: ActorData, need_shield: bool = False,
-                 shield_data: ActorData = None, can_be_removed: bool = True, can_be_added: bool = True, additional_asset_folders: list[str] = None):
+                 shield_data: ActorData = None, can_be_removed: bool = True, can_be_added: bool = True, 
+                 additional_asset_folders: list[str] = None):
         self.type = rdv_door_type
         self.need_shield = need_shield
         self.door = door_data
@@ -142,7 +156,7 @@ class DoorType(Enum):
             if e.type == type:
                 return e
 
-        raise ValueError(f"{type} is not a patchable door! Please check DoorType enum for list of patchable doors.")
+        raise ValueError(f"{type} is not a patchable door!")
 
 
 def is_door(actor: Container):
@@ -161,6 +175,7 @@ class DoorPatcher:
         }
         self.SHIELD = editor.resolve_actor_reference(_EXAMPLE_SHIELD)
         self.rename_all_shields()
+        self.patch_doorpresence_collision()
 
     def door_actor_to_type(self, door: Container, scenario: str) -> DoorType:
         """
@@ -226,7 +241,8 @@ class DoorPatcher:
         door_in_scenario_type = self.door_actor_to_type(door_actor, scenario)
         if door_in_scenario_type.can_be_removed is False:
             raise ValueError(
-                f"Base game door {door_in_scenario_type.type} cannot be patched!\nRequested door: {door_ref['actor']} in {scenario}")
+                f"Base game door {door_in_scenario_type.type} cannot be patched!" + \
+                    f"Requested door: {door_ref['actor']} in {scenario}")
 
         self.door_to_basic(door_actor, door_in_scenario_type, scenario)
         self.power_to_door_type(door_actor, door_type, scenario)
@@ -280,10 +296,8 @@ class DoorPatcher:
 
             shield_l = self.create_shield(scenario, door, door_type.shield, "L")
             shield_r = self.create_shield(scenario, door, door_type.shield, "R")
-            life_comp[
-                "wpLeftDoorShieldEntity"] = f"Root:pScenario:rEntitiesLayer:dctSublayers:default:dctActors:{shield_l.sName}"
-            life_comp[
-                "wpRightDoorShieldEntity"] = f"Root:pScenario:rEntitiesLayer:dctSublayers:default:dctActors:{shield_r.sName}"
+            life_comp["wpLeftDoorShieldEntity"] = self.editor.build_link(shield_l.sName)
+            life_comp["wpRightDoorShieldEntity"] = self.editor.build_link(shield_r.sName)
         
         # ensure assets are present
         for folder in door_type.required_asset_folders:
@@ -326,16 +340,18 @@ class DoorPatcher:
         for scenario in ALL_SCENARIOS:
             bmmap = self.editor.get_scenario_map(scenario)
             bmmap.raw.Root.mapBlockages = Container()
-    
+
     def rename_all_shields(self):
         for scenario in ALL_SCENARIOS:
             brfld = self.editor.get_scenario(scenario)
             
-            # we have to cache doors that have shields here and rename them outside the loop, as otherwise it will rename actors in the actor list and confuse the program. 
+            # we have to cache doors that have shields here and rename them outside the loop, 
+            # as otherwise it will rename actors in the actor list and confuse the program. 
             shielded_doors = []
             for layer_name, actor_name, actor in list(brfld.all_actors()):
 
-                # this is the door added to the Artaria CU. For some reason is_door crashes on this so we add a check here. 
+                # this is the door added to the Artaria CU. 
+                # For some reason is_door crashes on this so we add a check here. 
                 if actor_name == "DreadRando_CUDoor":
                     continue
 
@@ -346,10 +362,9 @@ class DoorPatcher:
                     continue
 
                 shielded_doors.append(actor)
-            
+
             for door in shielded_doors:
                 self.rename_shields(door, scenario)
-            
 
     def rename_shields(self, door: Container, scenario: str):
         life_comp = door.pComponents.LIFE
@@ -357,22 +372,23 @@ class DoorPatcher:
             link = life_comp[link_name]
             if link == "{EMPTY}":
                 continue
-            
+
             # get shield actor and cache its sName
             shieldActor = self.editor.resolve_actor_reference(self.editor.reference_for_link(link, scenario))
             old_sName = shieldActor.sName
 
-            # skip hdoors (doors where the environment covers one side of the door) as they have terrain attached to the ShieldEntity links
+            # skip hdoors (doors where the environment covers one side of the door) 
+            # as they have terrain attached to the ShieldEntity links
             if "db_hdoor" in old_sName:
                 continue
 
             # reclaim old shield id if this is a RandoShield
             self.reclaim_old_shield_id(shieldActor.sName, scenario)
-            
+
             # grab the lowest open id and rename it
             new_id = self.get_shield_id(scenario)
             shieldActor.sName = new_id
-            life_comp[link_name] = f"Root:pScenario:rEntitiesLayer:dctSublayers:default:dctActors:{new_id}"
+            life_comp[link_name] = self.editor.build_link(new_id)
 
             # make new actor, copy its groups, delete it
             brfld = self.editor.get_scenario(scenario)
@@ -383,14 +399,27 @@ class DoorPatcher:
             # update the minimap entry as well
             mapBlockages = self.editor.get_scenario_map(scenario).raw.Root.mapBlockages
             mapBlockages[new_id] = copy.deepcopy(mapBlockages[old_sName])
+
+            # flip the icon on rightfacing shields in order to optimize the icons file, 
+            # allowing room for new assets in custom_door_types.py
+            if link_name.startswith("wpRight"):
+                mapBlockages[new_id]["bFlipX"] = True
             mapBlockages.pop(old_sName)
 
     def get_shield_id(self, scenario: str):
         # since the available shield ids is auto sorted, just pop the first value
         return f"RandoShield_{self.available_shield_ids[scenario].pop(0)}"
-    
+
     def reclaim_old_shield_id(self, sName: str, scenario: str):
         # if it's a RandoShield, reclaim the old id after the underscore
         shieldId = int(sName.split("_")[1]) if "RandoShield" in sName else None
         if shieldId is not None:
-            insort(self.available_shield_ids[scenario], shieldId)
\ No newline at end of file
+            insort(self.available_shield_ids[scenario], shieldId)
+    
+    def patch_doorpresence_collision(self):
+        # extends the door collider in doorpresence actor to 300x300 to maintain the size of normal doors
+        # this looks a bit bad, but it'll do until we figure out how to edit navmeshes
+        # (or whatever is storing the intended hitboxes for doors)
+        doorpresence = self.editor.get_file("actors/props/doorpresence/collisions/doorpresence.bmscd", Bmscc)
+        door_collider = doorpresence.raw.layers[0].entries[0]
+        door_collider.data.max = ListContainer([300.0,320.0])
